{% extends 'crudlfap/form.html' %}

{% block breadcrumb %}
<nav class="breadcrumb">
  {% include 'crudlfap/_breadcrumb_object.html' %}
</nav>
{% endblock %}

{% block content %}
  {{ _('Are you sure you want to delete') }} {{ view.model._meta.verbose_name }} {{ object }} ?
  <br />
{% endblock %}

{% block buttons %}
  {{ render_button(_('Delete'), button_type="submit", button_class="btn-danger") }}
{% endblock %}
