<ul style="display: none" data-controller="messages">
  {% for message in messages %}
  <li class="{% if message.level == 25 %}teal{% endif %}{% if message.level == 30 %}orange darken-4{% endif %}">{{ message }}</li>
  {% endfor %}
</ul>
