{% extends 'base.html' %}

{% block content_open %}<div style="padding: 0 24px" id="modal-body-ajax">{% endblock %}

{% block breadcrumb %}
{% include 'crudlfap/_breadcrumb_object.html' %}
{% endblock %}

{% block content %}
{% include 'crudlfap/_list.html' %}
{% endblock %}

{% block after_container %}
{% with menu=view.menu_views %}
{% include 'crudlfap/_fixed_actions.html' %}
{% endwith %}
{% endblock %}
