{% extends 'base.html' %}

{% block body_class %}push-down{% endblock %}

{% block content %}
<h2>{{ _('You have been logged-out' ) }} !</h2>
<p>{{ _('Thanks for the time you spent with us today') }}</p>
{% endblock %}
