{% extends 'base.html' %}

{% block breadcrumb %}
  {% include 'crudlfap/_breadcrumb_object.html' %}
{% endblock %}

{% block content %}
<table class="table">
  <thead class="thead-inverse">
    {% for field in fields %}
    <tr>
        <th>
            {{ field['field'].name.capitalize() }}
        </th>
        <td>
            {{ field['value'] }}
        </td>
    </tr>
    {% endfor %}
  </tbody>
</table>
{% endblock %}

{% block after_container %}
{% with menu=view.menu_views %}
{% include 'crudlfap/_fixed_actions.html' %}
{% endwith %}
{% endblock %}
